@@ -1,5 +1,5 @@
 use crate::common::{
-    u8_high_low_get_u16, u16_get_u8_high, u16_get_u8_low, INDEX_SET_VALUE_HIGH,
+    u16_get_u8_high, u16_get_u8_low, u8_high_low_get_u16, INDEX_SET_VALUE_HIGH,
     INDEX_SET_VALUE_LOW, MESSAGE_LENGTH,
 };
 
@@ -16,6 +16,7 @@ pub fn set(voltage_mv: u16, message: &mut [u8; MESSAGE_LENGTH]) {
     message[INDEX_SET_VALUE_LOW] = u16_get_u8_low(command_voltage_value_mv_by10);
 }
 
+#[rustfmt::skip]
 #[cfg(test)]
 #[path = "./test_voltage.rs"]
 mod test_voltage;
